==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GPSCoordinates.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__double
import scala.jdk.CollectionConverters.*
final case class GPSCoordinates(latitude: __double, longitude: __double) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GPSCoordinates = {
    import GPSCoordinates.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
      .builder()
      .latitude(__double.unwrap(latitude): java.lang.Double)
      .longitude(__double.unwrap(longitude): java.lang.Double)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GPSCoordinates.ReadOnly =
    zio.aws.pinpoint.model.GPSCoordinates.wrap(buildAwsValue())
}
object GPSCoordinates {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GPSCoordinates =
      zio.aws.pinpoint.model.GPSCoordinates(latitude, longitude)
    def latitude: __double
    def longitude: __double
    def getLatitude: ZIO[Any, Nothing, __double] = ZIO.succeed(latitude)
    def getLongitude: ZIO[Any, Nothing, __double] = ZIO.succeed(longitude)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
  ) extends zio.aws.pinpoint.model.GPSCoordinates.ReadOnly {
    override val latitude: __double =
      zio.aws.pinpoint.model.primitives.__double(impl.latitude())
    override val longitude: __double =
      zio.aws.pinpoint.model.primitives.__double(impl.longitude())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
  ): zio.aws.pinpoint.model.GPSCoordinates.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GPSCoordinates.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__double
import scala.jdk.CollectionConverters.*
final case class GPSCoordinates(latitude: __double, longitude: __double) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GPSCoordinates = {
    import GPSCoordinates.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
      .builder()
      .latitude(latitude: java.lang.Double)
      .longitude(longitude: java.lang.Double)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GPSCoordinates.ReadOnly =
    zio.aws.pinpoint.model.GPSCoordinates.wrap(buildAwsValue())
}
object GPSCoordinates {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GPSCoordinates =
      zio.aws.pinpoint.model.GPSCoordinates(latitude, longitude)
    def latitude: __double
    def longitude: __double
    def getLatitude: ZIO[Any, Nothing, __double] = ZIO.succeed(latitude)
    def getLongitude: ZIO[Any, Nothing, __double] = ZIO.succeed(longitude)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
  ) extends zio.aws.pinpoint.model.GPSCoordinates.ReadOnly {
    override val latitude: __double = impl.latitude(): __double
    override val longitude: __double = impl.longitude(): __double
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GPSCoordinates
  ): zio.aws.pinpoint.model.GPSCoordinates.ReadOnly = new Wrapper(impl)
}
